=======
Credits
=======

Development Lead
----------------

* XESS Corp. <info@xess.com>

Contributors
------------

* Hasan Yavuz OZDERYA (https://github.com/hyOzd)
* John Donovan (https://github.com/GeoSpark)
* Adrien Descamps (https://github.com/descampsa)
* David Freitag (https://github.com/dvdfreitag)
